@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 BEGIN {
-	our $VERSION = 'v0.1.8'; # VERSION
+	our $VERSION = 'v0.1.9'; # VERSION
 }
 use Moose;
 use namespace::autoclean;
@@ -111,7 +111,7 @@ Business::CyberSource::Request::Capture - CyberSource Capture Request Object
 
 =head1 VERSION
 
-version v0.1.8
+version v0.1.9
 
 =head1 SYNOPSIS
 
@@ -150,13 +150,11 @@ Reader: client_env
 
 Type: Str
 
-This attribute is required.
-
 =head2 currency
 
 Reader: currency
 
-Type: Str
+Type: MooseX::Types::Varchar::Varchar[5]
 
 This attribute is required.
 
@@ -206,17 +204,17 @@ Type: Num
 
 Reader: username
 
-Type: Str
+Type: MooseX::Types::Varchar::Varchar[30]
 
 This attribute is required.
 
-Additional documentation: your merchantID
+Additional documentation: Your CyberSource merchant ID. Use the same merchantID for evaluation, testing, and production
 
 =head2 reference_code
 
 Reader: reference_code
 
-Type: Str
+Type: MooseX::Types::Varchar::Varchar[50]
 
 This attribute is required.
 
@@ -224,7 +222,7 @@ This attribute is required.
 
 Reader: foreign_currency
 
-Type: Str
+Type: MooseX::Types::Varchar::Varchar[5]
 
 =head2 client_name
 
@@ -232,16 +230,12 @@ Reader: client_name
 
 Type: Str
 
-This attribute is required.
-
 =head2 client_version
 
 Reader: client_version
 
 Type: Str
 
-This attribute is required.
-
 =head1 SEE ALSO
 
 =over
