@@ -5,10 +5,12 @@ use warnings;
 use Carp;
 our @CARP_NOT = qw( SOAP::Lite );
 
-our $VERSION = 'v0.1.8'; # VERSION
+our $VERSION = 'v0.1.9'; # VERSION
 
 use Moose::Role;
-use MooseX::Types::URI qw( Uri );
+use namespace::autoclean;
+use MooseX::Types::Varchar qw( Varchar );
+use MooseX::Types::URI     qw( Uri     );
 
 with qw(
 	Business::CyberSource
@@ -43,7 +45,7 @@ has _sdbo => (
 has reference_code => (
 	required => 1,
 	is       => 'ro',
-	isa      => 'Str',
+	isa      => Varchar[50],
 );
 
 sub _build_soap_request {
@@ -161,7 +163,7 @@ Business::CyberSource::Request::Role::Common - Request Role
 
 =head1 VERSION
 
-version v0.1.8
+version v0.1.9
 
 =head1 BUGS
 
